#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 lsp
version:              2.2.0.0
visibility:           public
id:                   lsp-2.2.0.0-1wTjR6m8XHMB9d0XTUKi2
key:                  lsp-2.2.0.0-1wTjR6m8XHMB9d0XTUKi2
license:              MIT
copyright:            Alan Zimmerman, 2016-2021
maintainer:           alan.zimm@gmail.com
author:               Alan Zimmerman
homepage:             https://github.com/haskell/lsp
synopsis:             Haskell library for the Microsoft Language Server Protocol
description:
    An implementation of the types, and basic message server to
    allow language implementors to support the Language Server
    Protocol for their specific language.

    An example of this is for Haskell via the Haskell Language
    Server, at https://github.com/haskell/haskell-language-server

category:             Development
abi:                  d437825491ec578d5d916c5e12476435
exposed:              True
exposed-modules:
    Language.LSP.Diagnostics, Language.LSP.Logging,
    Language.LSP.Protocol.Capabilities from lsp-types-2.0.2.0-dUFitFTJB7FQc8xMsVNi8:Language.LSP.Protocol.Capabilities,
    Language.LSP.Protocol.Lens from lsp-types-2.0.2.0-dUFitFTJB7FQc8xMsVNi8:Language.LSP.Protocol.Lens,
    Language.LSP.Protocol.Message from lsp-types-2.0.2.0-dUFitFTJB7FQc8xMsVNi8:Language.LSP.Protocol.Message,
    Language.LSP.Protocol.Types from lsp-types-2.0.2.0-dUFitFTJB7FQc8xMsVNi8:Language.LSP.Protocol.Types,
    Language.LSP.Server, Language.LSP.VFS

hidden-modules:
    Language.LSP.Server.Control Language.LSP.Server.Core
    Language.LSP.Server.Processing

import-dirs:          /usr/lib/ghc-9.6.6/site-local/lsp-2.2.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/lsp-2.2.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/lsp-2.2.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lsp
hs-libraries:         HSlsp-2.2.0.0-1wTjR6m8XHMB9d0XTUKi2
depends:
    aeson-2.2.0.0-4qLATSA6nfj1RfgXH6DMKK
    async-2.2.5-BExe3HBSFHr8hii1cT1bvS
    attoparsec-0.14.4-FIfeiNzOKYm3sEc1QPF51Z base-4.18.2.1
    bytestring-0.11.5.3 co-log-core-0.3.2.5-1l4Xb3jVXB2Kx3NkmnOyE3
    containers-0.6.7 data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz
    directory-1.3.8.5 exceptions-0.10.7 filepath-1.4.300.1
    hashable-1.4.7.0-LE3bCdm1Wgy6IgVYkRoAlQ
    lens-5.3.3-Ag3JywAjDxJ2k98xBhf4hs
    lens-aeson-1.2.3-LKwWspc3CGLABpwUtuPc2T
    lsp-types-2.0.2.0-dUFitFTJB7FQc8xMsVNi8 mtl-2.3.1
    prettyprinter-1.7.1-4PNEjQDcFkU8z4wKR8XxHs
    random-1.2.1.3-HzFGhfPSv5b3eeTVe0g48p
    row-types-1.0.1.2-1KPI2BY2URnDbZFtTY7TBE
    sorted-list-0.2.3.1-B7chDh8YH97F9UBUowDtaN stm-2.5.1.0
    temporary-1.3-7FXkQQKerYU7UfmRyKNwo9 text-2.0.2
    text-rope-0.3-8YuI8QHnRpR6wIaikFYuUd transformers-0.6.1.0
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY
    unordered-containers-0.2.20.1-I6eyTXb69D2BhxejMtPouo
    uuid-1.3.16-8QPIjurlhvP3hDFUxOgViN

haddock-interfaces:   /usr/share/doc/haskell-lsp/html/lsp.haddock
haddock-html:         /usr/share/doc/haskell-lsp/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

